This is unreleased documentation for the main (development) branch of crypto-glue.

Params

Struct Params 

pub struct Params<'k, 'l, 'c> {
    pub kin: &'k [u8],
    pub label: &'l [u8],
    pub context: &'c [u8],
    pub use_l: bool,
    pub use_separator: bool,
    pub use_counter: bool,
}
Parameters used for KBKDF.

For more details, read the official specification: NIST SP 800-108r1.

Fields

kin: &'k [u8]

Key-derivation key.

key that is used as an input to a key-derivation function (along with other input data) to derive keying material.

label: &'l [u8]

A string that identifies the purpose for the derived keying material, which is encoded as a bit string.

The encoding method for the Label is defined in a larger context, for example, in the protocol that uses a KDF.

context: &'c [u8]

A bit string containing the information related to the derived keying material.

It may include the identities of the parties who are deriving and/or using the derived keying material and, optionally, a nonce known by the parties who derive the keys.

use_l: bool

A flag indicating whether to update the Prf with the requested key length.

use_separator: bool

A flag indicating whether to separate the label from the context with a NULL byte.

use_counter: bool

A flag indicating whether to update the Prf with the iteration counter.

Implementations

Source

impl<'k, 'l, 'c> Params<'k, 'l, 'c>

pub fn builder(kin: &'k [u8]) -> ParamsBuilder<'k, 'l, 'c>

Create a new builder for Params